@@ -412,7 +412,7 @@ var groupPath = function(d) {
         upper_y = upper_node.y;
         lower_x = lower_node.x;
         lower_y = lower_node.y;
-        offset = 0;
+        offset = 0.1;
         retval =  "M" ;
         retval += (upper_x - offset  + icon_offset + x_offset) + "," + (upper_y - offset + icon_offset + y_offset) + "L";
         retval += (upper_x + offset + icon_offset + x_offset) + "," + (upper_y - offset + icon_offset + y_offset) + "L";
